/* Copyright (C) 2000-2002 Lavtech.com corp. All rights reserved.

   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 2 of the License, or
   (at your option) any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA 
*/

#ifndef _UDM_ROBOTS_H
#define _UDM_ROBOTS_H

extern UDM_ROBOT* UdmRobotFind(UDM_ROBOTS *Robots,const char *hostinfo);
extern UDM_ROBOT* UdmRobotAddEmpty(UDM_ROBOTS *Robots,const char *hostinfo);
extern UDM_ROBOT_RULE* UdmRobotRuleFind(UDM_ROBOTS *Robots,UDM_URL * URL);
extern int UdmRobotListFree(UDM_ROBOTS *Robots);
extern int UdmRobotParse(UDM_AGENT *Indexer, UDM_SERVER *Srv, char *content, const char *hostinfo);

#endif
